@@ -6,7 +6,7 @@ use utf8;
 use Carp;
 ## no critic (RequireCarping)
 
-our $VERSION = 'v0.1.5';
+our $VERSION = 'v0.1.6';
 
 use List::Util qw( first any );
 use File::Temp qw( tempfile ); # don't use Path::Tiny to have temp files in error $SHELL
@@ -58,8 +58,9 @@ sub get_steps {
         croak "unknown version '$prev'" if !$self->{paths}{$prev};
         croak "no one-step migration from '$prev' to '$next'" if !$self->{paths}{$prev}{$next};
         my @steps = @{ $self->{paths}{$prev}{$next} };
-        if (any { $_->{type} eq 'RESTORE' } @steps) {
-            @all_steps = @steps;
+        if (@all_steps && any { $_->{type} eq 'RESTORE' } @steps) {
+            my $v = $all_steps[0]{prev_version};
+            @all_steps = map { +{ %{$_}, prev_version=>$v } } @steps;
         }
         else {
             push @all_steps, @steps;
@@ -454,7 +455,7 @@ App::migrate - upgrade / downgrade project
 
 =head1 VERSION
 
-This document describes App::migrate version v0.1.5
+This document describes App::migrate version v0.1.6
 
 
 =head1 SYNOPSIS
